@@ -1,6 +1,7 @@
 import json
 import rainiee_data_test.pro.data_pro as data_pro
-from functools import partial
+from rainiee_data_test.common_client import CommonClient
+
 
 class DataClient(object):
 
@@ -13,11 +14,8 @@ class DataClient(object):
     def get_token(self):
         return data_pro.get_token()
 
-    def query(self,api_name,**kwargs):
-        return data_pro.get_rainiee_client().query(api_name, 'POST', req_param = kwargs)
-
-    def __getattr__(self, name):
-        return partial(self.query, api_name=name)
+    def vip_channel(self):
+        return CommonClient(data_pro)
 
     @staticmethod
     def cn_stock_realtime(symbol):
